==> kubernetes-model-extensions-6.6.1-sources.jar: io/fabric8/kubernetes/api/model/extensions/IngressStatusFluent.java <==
package io.fabric8.kubernetes.api.model.extensions;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface IngressStatusFluent<A extends IngressStatusFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildLoadBalancer instead.
   * @return The buildable object.
   */
  @Deprecated
  public IngressLoadBalancerStatus getLoadBalancer();
  public IngressLoadBalancerStatus buildLoadBalancer();
  public A withLoadBalancer(IngressLoadBalancerStatus loadBalancer);
  public Boolean hasLoadBalancer();
  public IngressStatusFluent.LoadBalancerNested<A> withNewLoadBalancer();
  public IngressStatusFluent.LoadBalancerNested<A> withNewLoadBalancerLike(IngressLoadBalancerStatus item);
  public IngressStatusFluent.LoadBalancerNested<A> editLoadBalancer();
  public IngressStatusFluent.LoadBalancerNested<A> editOrNewLoadBalancer();
  public IngressStatusFluent.LoadBalancerNested<A> editOrNewLoadBalancerLike(IngressLoadBalancerStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface LoadBalancerNested<N> extends Nested<N>,IngressLoadBalancerStatusFluent<IngressStatusFluent.LoadBalancerNested<N>>{
    public N and();
    public N endLoadBalancer();
    
  }
  
}

==> kubernetes-model-extensions-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/extensions/IngressStatusFluent.java <==
package io.fabric8.kubernetes.api.model.extensions;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface IngressStatusFluent<A extends IngressStatusFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildLoadBalancer instead.
   * @return The buildable object.
   */
  @Deprecated
  public IngressLoadBalancerStatus getLoadBalancer();
  public IngressLoadBalancerStatus buildLoadBalancer();
  public A withLoadBalancer(IngressLoadBalancerStatus loadBalancer);
  public Boolean hasLoadBalancer();
  public IngressStatusFluent.LoadBalancerNested<A> withNewLoadBalancer();
  public IngressStatusFluent.LoadBalancerNested<A> withNewLoadBalancerLike(IngressLoadBalancerStatus item);
  public IngressStatusFluent.LoadBalancerNested<A> editLoadBalancer();
  public IngressStatusFluent.LoadBalancerNested<A> editOrNewLoadBalancer();
  public IngressStatusFluent.LoadBalancerNested<A> editOrNewLoadBalancerLike(IngressLoadBalancerStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface LoadBalancerNested<N> extends Nested<N>,IngressLoadBalancerStatusFluent<IngressStatusFluent.LoadBalancerNested<N>>{
    public N and();
    public N endLoadBalancer();
    
  }
  
}
